package com.qy.worksheetsystem.controller;

import com.qy.worksheetsystem.model.MessageResult;
import com.qy.worksheetsystem.model.MessageResultV2;
import com.qy.worksheetsystem.util.DateUtil;
import com.qy.worksheetsystem.util.JWTUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @BelongsProject: workSheetSystem
 * @BelongsPackage: com.qy.worksheetsystem.controller
 * @Author: lhbj
 * @CreateTime: 2024-12-03  16:45
 * @Description: TODO
 * @Version: 1.0
 */
@RestController
@RequestMapping("/work/calendar")
@Api(value = "工作日历",tags="工作日历")
public class WorkCalendarController {

    @ApiOperation(value = "获取工作日历")
    @GetMapping("/getWorkCalendar")
    @ApiImplicitParams({
            @ApiImplicitParam(name="token",value="token",required=true,paramType="header",dataType="String"),
            @ApiImplicitParam(name="startDate",value="开始日期",required=true,paramType="query",dataType="String"),
            @ApiImplicitParam(name="endDate",value="结束日期",required=true,paramType="query",dataType="String"),
    })
    public MessageResult getWorkCalendar(@RequestHeader("token") String token, String startDate, String endDate) throws ParseException {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        String number = JWTUtil.getNumber(token);
        if(StringUtils.isEmpty(number)){
            return MessageResult.error("token异常");
        }
        if (DateUtil.isValidDate(startDate, endDate) == false) {
            return MessageResult.error("请输入正确的日期时间，日期格式例如2022-01-01");
        }

        Date start = sdf.parse(startDate);
        Date end = sdf.parse(endDate);

        if (start.getTime() > end.getTime()) {
            return MessageResult.error("开始时间不能大于结束时间");
        }

        Map<String, String> map = new HashMap<>();
        map.put("startDate", startDate);
        map.put("endDate", endDate);

        MessageResultV2 messageResult= MessageResultV2.success();
        messageResult.setData(map);
        return messageResult;
    }
}
